// Cube.cpp: implementation of the CCube class.
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "Cube.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CCube::CCube(double r, double x, double y, double z, double rx, double ry, double rz, double vx, double vy, double vz, double vrx, double vry, double vrz, bool changeable)
{
	m_r = float(r);
	m_rx = rx;
	m_ry = ry;
	m_rz = rz;
	m_x = x;
	m_y = y;
	m_z = z;
	m_vrx = vrx;
	m_vry = vry;
	m_vrz = vrz;
	m_vx = vx;
	m_vy = vy;
	m_vz = vz;
	m_changeable = changeable;

	if (!m_changeable)
	{
		m_num_list = glGenLists(1);
		glNewList(m_num_list, GL_COMPILE);
			glBegin(GL_POLYGON);
				glNormal3d(0.0,0.0,1.0);
				glVertex3d(-m_r,  m_r, m_r);
				glVertex3d(-m_r, -m_r, m_r);
				glVertex3d( m_r, -m_r, m_r);
				glVertex3d( m_r,  m_r, m_r);
			glEnd();

			glBegin(GL_POLYGON);
				glNormal3d(0.0,0.0,-1.0);
				glVertex3d(  m_r,  m_r, -m_r);
				glVertex3d(  m_r, -m_r, -m_r);
				glVertex3d( -m_r, -m_r, -m_r);
				glVertex3d( -m_r,  m_r, -m_r);
			glEnd();

			glBegin(GL_POLYGON);	
				glNormal3d(1.0,0.0,0.0);
				glVertex3d( m_r, m_r, m_r);
				glVertex3d( m_r, -m_r, m_r);
				glVertex3d( m_r, -m_r, -m_r);
				glVertex3d( m_r, m_r, -m_r);
			glEnd();

			glBegin(GL_POLYGON);
				glNormal3d(-1.0,0.0,0.0);
				glVertex3d( -m_r, m_r, m_r);
				glVertex3d( -m_r, m_r, -m_r);
				glVertex3d( -m_r, -m_r, -m_r);
				glVertex3d( -m_r, -m_r, m_r);
			glEnd();

			glBegin(GL_POLYGON);
				glNormal3d(0.0,1.0,0.0);
				glVertex3d( -m_r, -m_r, m_r);
				glVertex3d( -m_r, -m_r, -m_r);
				glVertex3d( m_r, -m_r, -m_r);
				glVertex3d( m_r, -m_r, m_r);
			glEnd();

			glBegin(GL_POLYGON);
				glNormal3d(0.0,-1.0,0.0);
				glVertex3d( -m_r, m_r, m_r);
				glVertex3d( m_r, m_r, m_r);
				glVertex3d( m_r, m_r, -m_r);
				glVertex3d( -m_r, m_r, -m_r);
			glEnd();

		glEndList();
	}
}

CCube::~CCube()
{
}

void CCube::Draw(float x, float y, float z)
{
	glPushMatrix();	
		glTranslated(m_x - x, m_y - y, m_z - z);
		glRotated(m_rx, 1.0, 0.0, 0.0);
		glRotated(m_ry, 0.0, 1.0, 0.0);
		glRotated(m_rz, 0.0, 0.0, 1.0);
		if (m_changeable)
		{
			glBegin(GL_POLYGON);
				glNormal3d(0.0,0.0,1.0);
				glVertex3d(-m_r,  m_r, m_r);
				glVertex3d(-m_r, -m_r, m_r);
				glVertex3d( m_r, -m_r, m_r);
				glVertex3d( m_r,  m_r, m_r);
			glEnd();

			glBegin(GL_POLYGON);
				glNormal3d(0.0,0.0,-1.0);
				glVertex3d(  m_r,  m_r, -m_r);
				glVertex3d(  m_r, -m_r, -m_r);
				glVertex3d( -m_r, -m_r, -m_r);
				glVertex3d( -m_r,  m_r, -m_r);
			glEnd();

			glBegin(GL_POLYGON);
				glNormal3d(1.0,0.0,0);
				glVertex3d( m_r, m_r, m_r);
				glVertex3d( m_r, -m_r, m_r);
				glVertex3d( m_r, -m_r, -m_r);
				glVertex3d( m_r, m_r, -m_r);
			glEnd();

			glBegin(GL_POLYGON);
				glNormal3d(-1.0,0.0,0);
				glVertex3d( -m_r, m_r, m_r);
				glVertex3d( -m_r, m_r, -m_r);
				glVertex3d( -m_r, -m_r, -m_r);
				glVertex3d( -m_r, -m_r, m_r);
			glEnd();

			glBegin(GL_POLYGON);
				glNormal3d(0.0,1.0,0);
				glVertex3d( -m_r, -m_r, m_r);
				glVertex3d( -m_r, -m_r, -m_r);
				glVertex3d( m_r, -m_r, -m_r);
				glVertex3d( m_r, -m_r, m_r);
			glEnd();

			glBegin(GL_POLYGON);
				glNormal3d(0.0,-1.0,0);			
				glVertex3d( -m_r, m_r, m_r);
				glVertex3d( m_r, m_r, m_r);
				glVertex3d( m_r, m_r, -m_r);
				glVertex3d( -m_r, m_r, -m_r);
			glEnd();
		}
		else
			glCallList(m_num_list); 		
	glPopMatrix();
}

void CCube::Update(int t)
{
	m_x += m_vx * t;
	m_y += m_vy * t;
	m_z += m_vz * t;

	m_rx += m_vrx * t;
	m_ry += m_vry * t;
	m_rz += m_vrz * t;

}
